@@ -60,19 +60,21 @@ const (
 )
 
 var (
-	startupProbeTimeout = flag.Duration("probe-period", -1, "run startup probe with given timeout")
+	startupProbeTimeout   = flag.Duration("probe-timeout", -1, "run startup probe with given timeout")
+	readinessProbeTimeout = flag.Duration("probe-period", -1, "run readiness probe with given timeout")
 
 	// This creates an abstract socket instead of an actual file.
 	unixSocketPath = "@/knative.dev/serving/queue.sock"
 )
 
 type config struct {
-	ContainerConcurrency   int    `split_words:"true" required:"true"`
-	QueueServingPort       string `split_words:"true" required:"true"`
-	UserPort               string `split_words:"true" required:"true"`
-	RevisionTimeoutSeconds int    `split_words:"true" required:"true"`
-	ServingReadinessProbe  string `split_words:"true" required:"true"`
-	EnableProfiling        bool   `split_words:"true"` // optional
+	ContainerConcurrency     int    `split_words:"true" required:"true"`
+	QueueServingPort         string `split_words:"true" required:"true"`
+	UserPort                 string `split_words:"true" required:"true"`
+	RevisionTimeoutSeconds   int    `split_words:"true" required:"true"`
+	ServingReadinessProbe    string `split_words:"true" required:"true"`
+	EnableProfiling          bool   `split_words:"true"` // optional
+	EnableHTTP2AutoDetection bool   `split_words:"true"` // optional
 
 	// Logging configuration
 	ServingLoggingConfig         string `split_words:"true" required:"true"`
@@ -106,8 +108,15 @@ func init() {
 func main() {
 	flag.Parse()
 
-	// If this is set, we run as a standalone binary to probe the queue-proxy.
-	if *startupProbeTimeout >= 0 {
+	var timeout time.Duration = -1
+
+	// If either of those are set, we run as a standalone binary to probe the queue-proxy.
+	if startupProbeTimeout != nil && *startupProbeTimeout >= 0 {
+		timeout = *startupProbeTimeout
+	} else if readinessProbeTimeout != nil && *readinessProbeTimeout >= 0 {
+		timeout = *readinessProbeTimeout
+	}
+	if timeout >= 0 {
 		// Use a unix socket rather than TCP to avoid going via entire TCP stack
 		// when we're actually in the same container.
 		transport := http.DefaultTransport.(*http.Transport).Clone()
@@ -115,7 +124,7 @@ func main() {
 			return net.Dial("unix", unixSocketPath)
 		}
 
-		os.Exit(standaloneProbeMain(*startupProbeTimeout, transport))
+		os.Exit(standaloneProbeMain(timeout, transport))
 	}
 
 	// Otherwise, we run as the queue-proxy service.
@@ -165,7 +174,7 @@ func main() {
 	}()
 
 	// Setup probe to run for checking user-application healthiness.
-	probe := buildProbe(logger, env.ServingReadinessProbe)
+	probe := buildProbe(logger, env)
 	healthState := health.NewState()
 
 	mainServer := buildServer(ctx, env, healthState, probe, stats, logger)
@@ -254,11 +263,14 @@ func main() {
 	}
 }
 
-func buildProbe(logger *zap.SugaredLogger, probeJSON string) *readiness.Probe {
-	coreProbe, err := readiness.DecodeProbe(probeJSON)
+func buildProbe(logger *zap.SugaredLogger, env config) *readiness.Probe {
+	coreProbe, err := readiness.DecodeProbe(env.ServingReadinessProbe)
 	if err != nil {
 		logger.Fatalw("Queue container failed to parse readiness probe", zap.Error(err))
 	}
+	if env.EnableHTTP2AutoDetection {
+		return readiness.NewProbeWithHTTP2AutoDetection(coreProbe)
+	}
 	return readiness.NewProbe(coreProbe)
 }
 
@@ -272,7 +284,7 @@ func buildServer(ctx context.Context, env config, healthState *health.State, rp
 
 	target := net.JoinHostPort("127.0.0.1", env.UserPort)
 
-	httpProxy := pkghttp.NewHeaderPruningReverseProxy(target, activator.RevisionHeaders)
+	httpProxy := pkghttp.NewHeaderPruningReverseProxy(target, pkghttp.NoHostOverride, activator.RevisionHeaders)
 	httpProxy.Transport = buildTransport(env, logger, maxIdleConns)
 	httpProxy.ErrorHandler = pkgnet.ErrorHandler(logger)
 	httpProxy.BufferPool = network.NewBufferPool()
@@ -296,7 +308,9 @@ func buildServer(ctx context.Context, env config, healthState *health.State, rp
 	if metricsSupported {
 		composedHandler = requestMetricsHandler(logger, composedHandler, env)
 	}
-	composedHandler = tracing.HTTPSpanMiddleware(composedHandler)
+	if tracingEnabled {
+		composedHandler = tracing.HTTPSpanMiddleware(composedHandler)
+	}
 
 	composedHandler = health.ProbeHandler(healthState, rp.ProbeContainer, rp.IsAggressive(), tracingEnabled, composedHandler)
 	composedHandler = network.NewProbeHandler(composedHandler)
